@@ -32,8 +32,13 @@ if [ $retval != 0 ]; then
   exit 1
 fi
 
-extract `(cd $TARGET/var/cache/apt/archives && ls *.deb) | cut -d _ -f 1`
+extract `(cd $TARGET/var/cache/apt/archives && \
+	for i in *.deb; do dpkg --info $i | grep ^\ Priority:.required \
+	&& echo $i; done) | cut -d _ -f 1`
 
+if [ -e $TARGET/var/cache/apt/archives/gnumach_* ] ; then
+        extract gnumach
+fi
 
 x_feign_install dpkg
 if [ "$DEB_TARGET_GNU_SYSTEM" = "gnu" ] ; then
@@ -63,8 +68,38 @@ fi
 
 cp /usr/share/crosshurd/native-install $TARGET
 
+##################
+# Setup hostname.
+##################
+echo "I: Preparing /etc/hostname using `hostname`..."
+echo `hostname` > $TARGET/etc/hostname
+
+###################
+# Setup /etc/hosts
+###################
+echo "I: Preparing /etc/hosts..."
+
+echo "127.0.0.1		localhost `hostname`" > $TARGET/etc/hosts
+
+#########################
+# Setup /etc/resolv.conf
+#########################
+echo "I: Preparing /etc/resolv.conf..."
+
+if [ -e /etc/resolv.conf ] ; then
+	echo Copying this machine\'s resolv.conf to the new partition.
+	echo If this is not correct, please edit.
+	cp /etc/resolv.conf $TARGET/etc/resolv.conf
+else
+	echo Setting up bogus file, PLEASE EDIT.
+	echo "domain ${domainname}" > $TARGET/etc/resolv.conf
+	echo "search localnet" >> $TARGET/etc/resolv.conf
+	echo "nameserver WWW.XXX.YYY.ZZZ" >> $TARGET/etc/resolv.conf
+fi
+
 # more possibly interesting hooks from Marcus' cross-hurd follow
 # we don't use them for now.
+
 exit 0
 
 #####################################
@@ -129,36 +164,3 @@ if [ ! -e ${dest}/etc/rc0.d ] ; then
         done
         install -d -m 755 -o root -g root ${dest}/etc/rc.boot
 fi
-
-##################
-# Setup hostname.
-##################
-echo
-echo "Hey, ${hostname} is really a nice hostname for your machine!"
-
-echo ${hostname} > ${dest}/etc/hostname
-
-###################
-# Setup /etc/hosts
-###################
-echo
-echo "Preparing /etc/hosts."
-
-echo "127.0.0.1		localhost ${hostname}" > ${dest}/etc/hosts
-
-#########################
-# Setup /etc/resolv.conf
-#########################
-echo
-echo "Preparing /etc/resolv.conf."
-
-if [ -e /etc/resolv.conf ] ; then
-	echo Copying this machine\'s resolv.conf to the Hurd partition.
-	echo If this is not correct, please edit.
-	cp /etc/resolv.conf ${dest}/etc/resolv.conf
-else
-	echo Setting up bogus file, PLEASE EDIT.
-	echo "domain ${domainname}" > ${dest}/etc/resolv.conf
-	echo "search localnet" >> ${dest}/etc/resolv.conf
-	echo "nameserver WWW.XXX.YYY.ZZZ" >> ${dest}/etc/resolv.conf
-fi
